<?php

namespace FiloBlu\Kpi\Model;

class Core
{
    protected $_productCollection;
    protected $_scopeConfig;
    protected $_resource;
    protected $_customerFactory;
    protected $_productRepositoryInterface;

    protected $_productConfigurable;
    protected $_filesystem;
    protected $_adapterFactory;
    protected $_storeManagerInterface;
    protected $_productAction;

    protected $connection;

    protected $_helper;

    public function __construct(
        \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollection,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Framework\App\ResourceConnection $resource,
        \Magento\Customer\Model\ResourceModel\Customer\CollectionFactory $customerFactory,
        \Magento\Catalog\Api\ProductRepositoryInterface $productRepositoryInterface,
        \FiloBlu\Kpi\Helper\Data $helper,

        \Magento\ConfigurableProduct\Model\ResourceModel\Product\Type\Configurable $productConfigurable,
        \Magento\Framework\Filesystem $filesystem,
        \Magento\Framework\Image\AdapterFactory $adapterFactory,
        \Magento\Store\Model\StoreManagerInterface $storeManagerInterface,
        \Magento\Catalog\Model\ResourceModel\Product\Action $productAction
    ) {
        $this->_productCollection = $productCollection;
        $this->_scopeConfig = $scopeConfig;
        $this->_resource = $resource;
        $this->_customerFactory = $customerFactory;
        $this->_productRepositoryInterface = $productRepositoryInterface;
        $this->_helper = $helper;

        $this->_productConfigurable = $productConfigurable;
        $this->_filesystem = $filesystem;
        $this->_adapterFactory = $adapterFactory;
        $this->_storeManagerInterface = $storeManagerInterface;
        $this->_productAction = $productAction;
    }

    protected function getConnection()
    {
        if (!$this->connection) {
            $this->connection = $this->_resource->getConnection('core_write');
        }
        return $this->connection;
    }

    protected function getCustomerCollection()
    {
        return $this->_customerFactory->create();
    }

    protected function getProductsCollection()
    {
        return $this->_productCollection->create();
    }

    protected  function getDefaultStoreIds($get_only_first = false)
    {
        $result = array();
        $fallback_to_store_id = 1;

        $affected_stores = trim($this->_scopeConfig->getValue('kpi/table_configuration/affectedstores'));

        // Fallback store ID 1
        if(!$affected_stores){
            $result[] = $fallback_to_store_id;
            return $result;
        }

        $store_codes = explode(",",$affected_stores);
        $store_codes = array_map('trim',$store_codes);

        $all_stores = $this->_storeManagerInterface->getStores();

        foreach ($store_codes as $store_code) {
            foreach($all_stores as $store){
                if($store->getCode() == $store_code){
                    $result[] = $store->getId();
                }
            }
        }

        //Fallback to default store 1 if none is found
        if (count($result) == 0){
            $result = array();
            $result[] = $fallback_to_store_id;
        }

        if ($get_only_first){
            return $result[0];
        } else {
            return $result;
        }
    }

}
